@@ -11,13 +11,14 @@
 -- no effect at all.
 module Control.Exception.Assert.Sugar
   ( assert, blame, showFailure, swith, allB
-  , failure, twith, forceEither
+    -- * DEPRECATED
+  , twith, failure, forceEither
   ) where
 
-import Control.Exception (assert)
-import Data.Text (Text)
-import Debug.Trace (trace)
-import Prelude
+import           Control.Exception (assert)
+import           Data.Text (Text)
+import           Debug.Trace (trace)
+import           Prelude
 import qualified Text.Show.Pretty as Show.Pretty (ppShow)
 
 infix 1 `blame`
@@ -26,15 +27,72 @@ infix 1 `blame`
 --
 -- > assert (age < 120 `blame` age) $ savings / (120 - age)
 blame :: Show a => Bool -> a -> Bool
-{-# INLINE blame #-}
+{-# NOINLINE blame #-}
 blame True _ = True
 blame False blamed = trace (blameMessage blamed) False
 
 blameMessage :: Show a => a -> String
-{-# NOINLINE blameMessage #-}
 blameMessage blamed = "Contract failed and the following is to blame:\n  "
                       ++ Show.Pretty.ppShow blamed
 
+infix 2 `showFailure`
+-- | A helper function for 'error'. To be used as in
+--
+-- > case xs of
+-- >   0 : _ -> error $ "insignificant zero" `showFailure` xs
+--
+-- Fixing the first argument to @String@ instead of anything Showable
+-- prevents warnings about defaulting, even when @OverloadedStrings@
+-- extension is enabled.
+showFailure :: Show v => String -> v -> String
+{-# NOINLINE showFailure #-}
+showFailure s v =
+  "Internal failure occurred and the following is to blame:\n  "
+  ++ s ++ "\n  "
+  ++ Show.Pretty.ppShow v
+
+infix 2 `swith`
+-- | Syntactic sugar for the pair operation, to be used for 'blame' as in
+--
+-- > assert (age < 120 `blame` "age too high" `swith` age) $ savings / (120 - age)
+--
+-- Fixing the first component of the pair to @String@ prevents warnings
+-- about defaulting, even when @OverloadedStrings@ extension is enabled.
+swith :: String -> v -> (String, v)
+{-# INLINE swith #-}
+swith s v = (s, v)
+
+-- | Like 'List.all', but if the predicate fails, blame all the list elements
+-- and especially those for which it fails. To be used as in
+--
+-- > assert (allB (<= height) [yf, y1, y2])
+allB :: Show a => (a -> Bool) -> [a] -> Bool
+{-# NOINLINE allB #-}
+allB predicate l = case all predicate l of
+  True -> True
+  False -> trace (allBMessage predicate l) False
+
+allBMessage :: Show a => (a -> Bool) -> [a] -> String
+allBMessage predicate l =
+  "The following items on the list don't respect the contract:\n"
+  ++ Show.Pretty.ppShow (filter (not . predicate) l)
+  ++ "\nout of all the list items below:\n"
+  ++ Show.Pretty.ppShow l
+
+-- * DEPRECATED
+
+infix 2 `twith`
+-- | Syntactic sugar for the pair operation, to be used for 'blame' as in
+--
+-- > assert (age < 120 `blame` "age too high" `twith` age) $ savings / (120 - age)
+-- Fixing the first component of the pair to @Text@ prevents warnings
+-- about defaulting, even when @OverloadedStrings@ extension is enabled.
+{-# DEPRECATED twith
+      "consider using 'swith' instead, for simplicity, because GHC optimizes lazy 'String' constants very well." #-}
+twith :: Text -> b -> (Text, b)
+{-# INLINE twith #-}
+twith t b = (t, b)
+
 infix 1 `failure`
 -- | Like 'error', but shows the source position (in newer GHCs
 -- @error@ shows source position as well, hence deprecation)
@@ -54,59 +112,6 @@ failure asrt blamed =
      $ error "Control.Exception.Assert.Sugar.failure"
          -- Lack of no-ignore-asserts or GHC < 7.4.
 
-infix 2 `showFailure`
--- | A helper function for 'error'. To be used as in
---
--- > case xs of
--- >   0 : _ -> error $ "insignificant zero" `showFailure` xs
---
--- Fixing the first argument to @String@ instead of anything Showable
--- prevents warnings about defaulting, even when @OverloadedStrings@
--- extension is enabled.
-showFailure :: Show v => String -> v -> String
-{-# NOINLINE showFailure #-}
-showFailure s v =
-  "Internal failure occurred and the following is to blame:\n  "
-  ++ s ++ "\n  "
-  ++ Show.Pretty.ppShow v
-
-infix 2 `twith`
--- | Syntactic sugar for the pair operation, to be used for 'blame' as in
---
--- > assert (age < 120 `blame` "age too high" `twith` age) $ savings / (120 - age)
--- Fixing the first component of the pair to @Text@ prevents warnings
--- about defaulting, even when @OverloadedStrings@ extension is enabled.
-{-# DEPRECATED twith
-      "consider using 'swith' instead, for simplicity, because GHC optimizes lazy 'String' constants very well." #-}
-twith :: Text -> b -> (Text, b)
-{-# INLINE twith #-}
-twith t b = (t, b)
-
-infix 2 `swith`
--- | Syntactic sugar for the pair operation, to be used for 'blame' as in
---
--- > assert (age < 120 `blame` "age too high" `swith` age) $ savings / (120 - age)
---
--- Fixing the first component of the pair to @String@ prevents warnings
--- about defaulting, even when @OverloadedStrings@ extension is enabled.
-swith :: String -> v -> (String, v)
-{-# INLINE swith #-}
-swith s v = (s, v)
-
--- | Like 'List.all', but if the predicate fails, blame all the list elements
--- and especially those for which it fails. To be used as in
---
--- > assert (allB (<= height) [yf, y1, y2])
-allB :: Show a => (a -> Bool) -> [a] -> Bool
-{-# INLINE allB #-}
-allB predicate l = blame (all predicate l) $ allBMessage predicate l
-
-allBMessage :: Show a => (a -> Bool) -> [a] -> String
-{-# NOINLINE allBMessage #-}
-allBMessage predicate l = Show.Pretty.ppShow (filter (not . predicate) l)
-                          ++ " in the context of "
-                          ++ Show.Pretty.ppShow l
-
 infix 1 `forceEither`
 -- | Assuming that @Left@ signifies an error condition,
 -- check the @Either@ value and, if @Left@ is encountered,
